@@ -1,23 +1,9 @@
-/********************************************************************
- KSld - the KDE Screenlocker Daemon
- This file is part of the KDE project.
+/*
+SPDX-FileCopyrightText: 1999 Martin R. Jones <mjones@kde.org>
+SPDX-FileCopyrightText: 2011 Martin Gräßlin <mgraesslin@kde.org>
 
-Copyright 1999 Martin R. Jones <mjones@kde.org>
-Copyright (C) 2011 Martin Gräßlin <mgraesslin@kde.org>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "interface.h"
 #include "kscreensaveradaptor.h"
 #include "ksldapp.h"
@@ -26,8 +12,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // KDE
 #include <KAuthorized>
 #include <KIdleTime>
+#include <KWindowSystem>
 // Qt
 #include <QDBusConnection>
+#include <QDBusContext>
 #include <QDBusReply>
 #include <QDBusServiceWatcher>
 #include <QRandomGenerator>
@@ -78,6 +66,10 @@ uint Interface::GetActiveTime()
 
 uint Interface::GetSessionIdleTime()
 {
+    if (KWindowSystem::isPlatformWayland()) {
+        QDBusContext::sendErrorReply(QDBusError::NotSupported, QStringLiteral("GetSessionIdleTime is not supported on this platform"));
+        return 0;
+    }
     return KIdleTime::instance()->idleTime();
 }
 
