@@ -1,24 +1,10 @@
-/********************************************************************
- KSld - the KDE Screenlocker Daemon
- This file is part of the KDE project.
+/*
+SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+SPDX-FileCopyrightText: 2019 Kevin Ottens <kevin.ottens@enioka.com>
+SPDX-FileCopyrightText: 2020 David Redondo <kde@david-redondo.de>
 
-Copyright (C) 2014 Martin Gräßlin <mgraesslin@kde.org>
-Copyright (C) 2019 Kevin Ottens <kevin.ottens@enioka.com>
-Copyright (C) 2020 David Redondo <kde@david-redondo.de>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "kcm.h"
 #include "appearancesettings.h"
 #include "kscreenlockerdata.h"
@@ -53,7 +39,7 @@ ScreenLockerKcm::ScreenLockerKcm(QObject *parent, const KPluginMetaData &data, c
     qmlProtectModule(url, 1);
 
     // Our modules will be checking the Plasmoid attached object when running from Plasma, let it load the module
-    const char *uri = "org.kde.plasma.plasmoid";
+    constexpr const char *uri = "org.kde.plasma.plasmoid";
     qmlRegisterUncreatableType<QObject>(uri, 2, 0, "PlasmoidPlaceholder", QStringLiteral("Do not create objects of type Plasmoid"));
 
     connect(&KScreenSaverSettings::getInstance(),
